<!DOCTYPE html>
<html>
<head>
  <title>Login</title>
  <link type="text/css" rel="stylesheet" href="{{ static_url('css/example.css') }}" />
</head>
<body>
  <form method="post">
    <input type="text"     name="username" value="admin" /><br/>
    <input type="password" name="password" value="admin" /><br/>
    <input type="submit"   name="submit"   value="Login" /><br/>
  </form>
</body>
</html>
